"""Shared helpers for ensuring a Cloudflare tunnel and credentials exist."""

from __future__ import annotations

from pathlib import Path

from .service_install import TunnelInfo, ensure_tunnel_and_service


def ensure_tunnel_with_credentials(tunnel_name: str, *, config_path: Path) -> TunnelInfo:
    return ensure_tunnel_and_service(tunnel_name, config_path=config_path)


__all__ = ["ensure_tunnel_with_credentials"]
